Tarantool development patches archive
 help / color / mirror / Atom feed
From: Kirill Shcherbatov <kshcherbatov@tarantool.org>
To: tarantool-patches@freelists.org
Cc: "v.shpilevoy@tarantool.org" <v.shpilevoy@tarantool.org>
Subject: [tarantool-patches] Re: [PATCH v1 3/4] box: introduce box_space_id_by_name
Date: Mon, 4 Jun 2018 22:21:17 +0300	[thread overview]
Message-ID: <ff77971d-82e8-eee3-5715-d8d832662c11@tarantool.org> (raw)
In-Reply-To: <cb123cbe-e625-3464-840d-f909fc2fea3d@tarantool.org>

> 1. Lets change commit title: the patch does not introduce
> box_space_id_by_name. It was before the patch.
    box: port schema_find_id to C
    
    Part of #3273.

> 2. How can you return -1, when the return type is unsigned?
> 3. It is not 'space_id' speaking in general. This function is used in
> user.cc also to search user id by the name. Please, find another name
> for the parameter.
> 4. "new slab" -> "key". OutOfMemory takes size, alloc function and
> the result variable name.
> 5. You should avoid 'goto cleanup' here.

diff --git a/src/box/schema.cc b/src/box/schema.cc
index c5055ee..a85a09f 100644
--- a/src/box/schema.cc
+++ b/src/box/schema.cc
@@ -222,11 +222,11 @@ sc_space_new(uint32_t id, const char *name, struct key_def *key_def,
 	trigger_run_xc(&on_alter_space, space);
 }
 
-uint32_t
+int
 schema_find_id(uint32_t system_space_id, uint32_t index_id,
-	       const char *name, uint32_t len, uint32_t *space_id)
+	       const char *name, uint32_t len, uint32_t *object_id)
 {
-	*space_id = BOX_ID_NIL;
+	*object_id = BOX_ID_NIL;
 	if (len > BOX_NAME_MAX) {
 		diag_set(SystemError,
 			 "name length %d is greater than BOX_NAME_MAX", len);
@@ -248,7 +248,7 @@ schema_find_id(uint32_t system_space_id, uint32_t index_id,
 	uint32_t used = region_used(region);
 	char *key = (char *)region_alloc(region, size);
 	if (key == NULL) {
-		diag_set(OutOfMemory, size, "region", "new slab");
+		diag_set(OutOfMemory, size, "region", "key");
 		return -1;
 	}
 	mp_encode_str(key, name, len);
@@ -261,13 +261,10 @@ schema_find_id(uint32_t system_space_id, uint32_t index_id,
 	struct tuple *tuple;
 	if (iterator_next(it, &tuple) != 0) {
 		rc = -1;
-		goto cleanup;
-	}
-	if (tuple) {
+	} else if (tuple) {
 		/* id is always field #1 */
-		*space_id = tuple_field_u32_xc(tuple, 0);
+		*object_id = tuple_field_u32_xc(tuple, 0);
 	}
-cleanup:
 	iterator_delete(it);
 	region_truncate(region, used);
 	return rc;

> 6. Same. Do not mention space. It is a function to find ID of
> any system object. Not only space. This function is applicable
> for _index, _space, _user, _func.

diff --git a/src/box/schema.h b/src/box/schema.h
index 099f9b0..cd9bb5b 100644
--- a/src/box/schema.h
+++ b/src/box/schema.h
@@ -107,16 +107,16 @@ sequence_by_id(uint32_t id);
*
* @param system_space_id identifier of the system space.
* @param index_id identifier of the index to lookup.
  * @param name space to lookup name.
* @param len length of a name.
- * @param space_id[out] space_id BOX_ID_NIL - not found.
+ * @param object_id[out] object_id or BOX_ID_NIL - not found.
*
* @retval 0 on success.
* @retval -1 on error.
*/
-uint32_t
+int
schema_find_id(uint32_t system_space_id, uint32_t index_id,
- const char *name, uint32_t len, uint32_t *space_id);
+ const char *name, uint32_t len, uint32_t *object_id);
@@ -107,16 +107,16 @@ sequence_by_id(uint32_t id);
* @param system_space_id identifier of the system space.
* @param index_id identifier of the index to lookup.
- * @param name space to lookup name.
+ * @param name of object to lookup.
* @param len length of a name.

#if defined(__cplusplus)
} /* extern "C" */

  reply	other threads:[~2018-06-04 19:21 UTC|newest]

Thread overview: 23+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-05-31 11:22 [tarantool-patches] [PATCH v1 0/4] sql: remove Triggers to server Kirill Shcherbatov
2018-05-31 11:22 ` [tarantool-patches] [PATCH v1 1/4] box: move db->pShchema init to sql_init Kirill Shcherbatov
2018-05-31 17:36   ` [tarantool-patches] " Vladislav Shpilevoy
2018-06-01 20:24     ` Kirill Shcherbatov
2018-05-31 11:22 ` [tarantool-patches] [PATCH v1 2/4] sql: fix sql len in tarantoolSqlite3RenameTrigger Kirill Shcherbatov
2018-05-31 11:22 ` [tarantool-patches] [PATCH v1 3/4] box: introduce box_space_id_by_name Kirill Shcherbatov
2018-05-31 17:36   ` [tarantool-patches] " Vladislav Shpilevoy
2018-06-01 20:24     ` Kirill Shcherbatov
2018-06-04 13:27       ` Vladislav Shpilevoy
2018-06-04 19:21         ` Kirill Shcherbatov [this message]
2018-06-05 13:31           ` Vladislav Shpilevoy
2018-05-31 11:22 ` [tarantool-patches] [PATCH v1 4/4] sql: move Triggers to server Kirill Shcherbatov
2018-05-31 17:36   ` [tarantool-patches] " Vladislav Shpilevoy
2018-06-01 20:24     ` Kirill Shcherbatov
2018-06-01 20:25       ` Kirill Shcherbatov
2018-06-04 13:27         ` Vladislav Shpilevoy
2018-06-04 19:21           ` Kirill Shcherbatov
2018-06-05 13:31             ` Vladislav Shpilevoy
2018-06-09  9:32               ` Kirill Shcherbatov
2018-06-01 18:51   ` Konstantin Osipov
2018-05-31 17:36 ` [tarantool-patches] Re: [PATCH v1 0/4] sql: remove " Vladislav Shpilevoy
2018-06-04 13:27 ` Vladislav Shpilevoy
2018-06-05 13:31 ` Vladislav Shpilevoy

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=ff77971d-82e8-eee3-5715-d8d832662c11@tarantool.org \
    --to=kshcherbatov@tarantool.org \
    --cc=tarantool-patches@freelists.org \
    --cc=v.shpilevoy@tarantool.org \
    --subject='[tarantool-patches] Re: [PATCH v1 3/4] box: introduce box_space_id_by_name' \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox